pylint
Author: Stephan Müller

##### lccalib.averaging

| Line | Column | Type | Object | Message | Symbol | Message Id
--- | --- | --- | --- | --- | --- | --- | ---
Source | 331 | 27 | warning |  | todo remove this as soon as mklc is fixed | fixme | W0511
Source | 80 | 0 | refactor | star_lc_averager | Too many positional arguments (6/5) | too-many-positional-arguments | R0917
Source | 266 | 0 | refactor | night_averager | Too many positional arguments (6/5) | too-many-positional-arguments | R0917

##### lccalib.match

| Line | Column | Type | Object | Message | Symbol | Message Id
--- | --- | --- | --- | --- | --- | --- | ---
Source | 110 | 39 | error | NearestNeighAssoc.append | Possibly using variable 'l' before assignment | possibly-used-before-assignment | E0606
Source | 146 | 39 | error | NearestNeighAssoc.match | Possibly using variable 'l' before assignment | possibly-used-before-assignment | E0606
Source | 259 | 39 | error | NearestNeighAssocHealpy.append | Possibly using variable 'l' before assignment | possibly-used-before-assignment | E0606
Source | 291 | 39 | error | NearestNeighAssocHealpy.match | Possibly using variable 'l' before assignment | possibly-used-before-assignment | E0606

##### lccalib.zp

| Line | Column | Type | Object | Message | Symbol | Message Id
--- | --- | --- | --- | --- | --- | --- | ---
Source | 84 | 0 | refactor | plot_diff_mag | Too many positional arguments (7/5) | too-many-positional-arguments | R0917
Source | 131 | 0 | refactor | compute_zp | Too many positional arguments (7/5) | too-many-positional-arguments | R0917